Tools
=====

Prettypretty includes the following command line scripts to show off its
features:


.. autoprogram:: prettypretty.grid:create_parser()
    :prog: python -m prettypretty.grid
    :groups:


.. autoprogram:: prettypretty.progress:create_parser()
    :prog: python -m prettypretty.progress
    :groups:
